@@ -4,12 +4,13 @@ use glib::translate::*;
 use gst::subclass::prelude::*;
 
 use crate::{
+    ffi,
     prelude::*,
     video_codec_state::{Readable, VideoCodecState},
     VideoCodecFrame, VideoEncoder,
 };
 
-pub trait VideoEncoderImpl: VideoEncoderImplExt + ElementImpl {
+pub trait VideoEncoderImpl: ElementImpl + ObjectSubclass<Type: IsA<VideoEncoder>> {
     fn open(&self) -> Result<(), gst::ErrorMessage> {
         self.parent_open()
     }
@@ -84,53 +85,7 @@ pub trait VideoEncoderImpl: VideoEncoderImplExt + ElementImpl {
     }
 }
 
-pub trait VideoEncoderImplExt: ObjectSubclass {
-    fn parent_open(&self) -> Result<(), gst::ErrorMessage>;
-
-    fn parent_close(&self) -> Result<(), gst::ErrorMessage>;
-
-    fn parent_start(&self) -> Result<(), gst::ErrorMessage>;
-
-    fn parent_stop(&self) -> Result<(), gst::ErrorMessage>;
-
-    fn parent_finish(&self) -> Result<gst::FlowSuccess, gst::FlowError>;
-
-    fn parent_set_format(
-        &self,
-        state: &VideoCodecState<'static, Readable>,
-    ) -> Result<(), gst::LoggableError>;
-
-    fn parent_handle_frame(
-        &self,
-        frame: VideoCodecFrame,
-    ) -> Result<gst::FlowSuccess, gst::FlowError>;
-
-    fn parent_flush(&self) -> bool;
-
-    fn parent_negotiate(&self) -> Result<(), gst::LoggableError>;
-
-    fn parent_caps(&self, filter: Option<&gst::Caps>) -> gst::Caps;
-
-    fn parent_sink_event(&self, event: gst::Event) -> bool;
-
-    fn parent_sink_query(&self, query: &mut gst::QueryRef) -> bool;
-
-    fn parent_src_event(&self, event: gst::Event) -> bool;
-
-    fn parent_src_query(&self, query: &mut gst::QueryRef) -> bool;
-
-    fn parent_propose_allocation(
-        &self,
-        query: &mut gst::query::Allocation,
-    ) -> Result<(), gst::LoggableError>;
-
-    fn parent_decide_allocation(
-        &self,
-        query: &mut gst::query::Allocation,
-    ) -> Result<(), gst::LoggableError>;
-}
-
-impl<T: VideoEncoderImpl> VideoEncoderImplExt for T {
+pub trait VideoEncoderImplExt: VideoEncoderImpl {
     fn parent_open(&self) -> Result<(), gst::ErrorMessage> {
         unsafe {
             let data = Self::type_data();
@@ -478,6 +433,8 @@ impl<T: VideoEncoderImpl> VideoEncoderImplExt for T {
     }
 }
 
+impl<T: VideoEncoderImpl> VideoEncoderImplExt for T {}
+
 unsafe impl<T: VideoEncoderImpl> IsSubclassable<T> for VideoEncoder {
     fn class_init(klass: &mut glib::Class<Self>) {
         Self::parent_class_init::<T>(klass);
