@@ -2,7 +2,7 @@
 
 use std::{ops, ptr};
 
-use crate::VideoFrameExt;
+use crate::{ffi, prelude::*};
 use glib::{prelude::*, translate::*};
 
 #[derive(Debug)]
@@ -77,16 +77,20 @@ impl VideoConverter {
     #[cfg_attr(docsrs, doc(cfg(feature = "v1_22")))]
     #[doc(alias = "get_in_info")]
     #[doc(alias = "gst_video_converter_get_in_info")]
-    pub fn in_info(&self) -> crate::VideoInfo {
-        unsafe { from_glib_none(ffi::gst_video_converter_get_in_info(self.0.as_ptr())) }
+    pub fn in_info(&self) -> &crate::VideoInfo {
+        unsafe {
+            &*(ffi::gst_video_converter_get_in_info(self.0.as_ptr()) as *const crate::VideoInfo)
+        }
     }
 
     #[cfg(feature = "v1_22")]
     #[cfg_attr(docsrs, doc(cfg(feature = "v1_22")))]
     #[doc(alias = "get_out_info")]
     #[doc(alias = "gst_video_converter_get_out_info")]
-    pub fn out_info(&self) -> crate::VideoInfo {
-        unsafe { from_glib_none(ffi::gst_video_converter_get_out_info(self.0.as_ptr())) }
+    pub fn out_info(&self) -> &crate::VideoInfo {
+        unsafe {
+            &*(ffi::gst_video_converter_get_out_info(self.0.as_ptr()) as *const crate::VideoInfo)
+        }
     }
 
     #[doc(alias = "gst_video_converter_frame")]
